==> 1.4.3.tar.gz: lib/model/new_recurrence.dart <==
// ignore_for_file: unused_element, unused_import
// ignore_for_file: always_put_required_named_parameters_first
// ignore_for_file: constant_identifier_names
// ignore_for_file: lines_longer_than_80_chars

part of cresce.api;

class NewRecurrence {
  /// Returns a new [NewRecurrence] instance.
  NewRecurrence({
    required this.type,
    this.weekDays = const [],
    required this.start,
    required this.end,
  });

  final String type;
  final List<String> weekDays;
  final DateTime start;
  final DateTime end;

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is NewRecurrence &&
          other.type == type &&
          other.weekDays == weekDays &&
          other.start == start &&
          other.end == end;

  @override
  int get hashCode =>
      // ignore: unnecessary_parenthesis
      (type.hashCode) + (weekDays.hashCode) + (start.hashCode) + (end.hashCode);

  @override
  String toString() =>
      'NewRecurrence[type=$type, weekDays=$weekDays, start=$start, end=$end]';

  Map<String, dynamic> toJson() {
    final json = <String, dynamic>{};
    json[r'type'] = type;
    json[r'weekDays'] = weekDays;
    json[r'start'] = start.toUtc().toIso8601String();
    json[r'end'] = end.toUtc().toIso8601String();
    return json;
  }

  /// Returns a new [NewRecurrence] instance and imports its values from
  /// [value] if it's a [Map], null otherwise.
  // ignore: prefer_constructors_over_static_methods
  static NewRecurrence fromJson(dynamic value) {
    final json = value.cast<String, dynamic>();
    return NewRecurrence(
      type: mapValueOfType<String>(json, r'type')!,
      weekDays: (json[r'weekDays'] as List).cast<String>(),
      start: mapDateTime(json, r'start', '')!,
      end: mapDateTime(json, r'end', '')!,
    );
  }

  static List<NewRecurrence> listFromJson(dynamic json) =>
      json is List && json.isNotEmpty
          ? json.map(NewRecurrence.fromJson).toList()
          : <NewRecurrence>[];

  static Map<String, NewRecurrence> mapFromJson(dynamic json) {
    final map = <String, NewRecurrence>{};
    if (json is Map && json.isNotEmpty) {
      json.cast<String, dynamic>().forEach(
          (key, dynamic value) => map[key] = NewRecurrence.fromJson(value));
    }
    return map;
  }

  // maps a json object with a list of NewRecurrence-objects as value to a dart map
  static Map<String, List<NewRecurrence>> mapListFromJson(dynamic json) {
    final map = <String, List<NewRecurrence>>{};
    if (json is Map && json.isNotEmpty) {
      json.cast<String, dynamic>().forEach((key, dynamic value) {
        map[key] = NewRecurrence.listFromJson(value);
      });
    }
    return map;
  }
}

==> 1.4.5.tar.gz: lib/model/new_recurrence.dart <==
// ignore_for_file: unused_element, unused_import
// ignore_for_file: always_put_required_named_parameters_first
// ignore_for_file: constant_identifier_names
// ignore_for_file: lines_longer_than_80_chars

part of cresce.api;

class NewRecurrence {
  /// Returns a new [NewRecurrence] instance.
  NewRecurrence({
    required this.type,
    this.weekDays = const [],
    required this.start,
    required this.end,
  });

  String? type;

  List<String>? weekDays;

  DateTime? start;

  DateTime? end;

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is NewRecurrence &&
          other.type == type &&
          other.weekDays == weekDays &&
          other.start == start &&
          other.end == end;

  @override
  int get hashCode =>
      // ignore: unnecessary_parenthesis
      (type == null ? 0 : type.hashCode) +
      (weekDays == null ? 0 : weekDays.hashCode) +
      (start == null ? 0 : start.hashCode) +
      (end == null ? 0 : end.hashCode);

  @override
  String toString() =>
      'NewRecurrence[type=$type, weekDays=$weekDays, start=$start, end=$end]';

  Map<String, dynamic> toJson() {
    final json = <String, dynamic>{};
    json[r'type'] = type;
    json[r'weekDays'] = weekDays;
    json[r'start'] = start!.toUtc().toIso8601String();
    json[r'end'] = end!.toUtc().toIso8601String();
    return json;
  }

  /// Returns a new [NewRecurrence] instance and imports its values from
  /// [value] if it's a [Map], null otherwise.
  // ignore: prefer_constructors_over_static_methods
  static NewRecurrence fromJson(dynamic value) {
    final json = value.cast<String, dynamic>();
    return NewRecurrence(
      type: mapValueOfType<String>(json, r'type'),
      weekDays: json[r'weekDays'] is List
          ? (json[r'weekDays'] as List).cast<String>()
          : null,
      start: mapDateTime(json, r'start', ''),
      end: mapDateTime(json, r'end', ''),
    );
  }

  static List<NewRecurrence> listFromJson(dynamic json) =>
      json.map(NewRecurrence.fromJson).toList();

  static Map<String, NewRecurrence> mapFromJson(dynamic json) {
    final map = <String, NewRecurrence>{};
    if (json is Map && json.isNotEmpty) {
      json.cast<String, dynamic>().forEach(
          (key, dynamic value) => map[key] = NewRecurrence.fromJson(value));
    }
    return map;
  }

  // maps a json object with a list of NewRecurrence-objects as value to a dart map
  static Map<String, List<NewRecurrence>> mapListFromJson(dynamic json) {
    final map = <String, List<NewRecurrence>>{};
    if (json is Map && json.isNotEmpty) {
      json.cast<String, dynamic>().forEach((key, dynamic value) {
        map[key] = NewRecurrence.listFromJson(value);
      });
    }
    return map;
  }
}
